Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AllDirectories ¶
AllDirectories return all directory and sub-directory in path
Types ¶
type DocTags ¶
type DocTags []string
DocTags is tag in godoc
func ParseDocTag ¶
ParseDocTag to parse tag from document tag
type ProjectContext ¶
type ProjectContext struct {
// Layouts contain project layout and folders
Packages []string
// Autowires is list of function what eligible to automatic add to DI
Autowires []string
// Automocks is list of file path to be generated the mock
Automocks []string
}
ProjectContext is project context
func Parse ¶
func Parse(appPath string) (projCtx ProjectContext, err error)
Parse the source code to get autowire and automock
Click to show internal directories.
Click to hide internal directories.