package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Jul 24, 2019
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package timekit provide error safe function for time function
Duration is error safe function for time.Parse()
EqualString return whether time is same with string
EqualUTC return whether time is same with UTC string
Parse is error safe function time.Parse()
func Sleep(durationFormat string)
Sleep pause current goroutine according duration format
UTC is error safe function time.Parse() using RFC3339
Source Files
¶
Click to show internal directories.
Click to hide internal directories.